@@ -1,4 +1,5 @@
 bcontSurvGunivInform <- function(params, respvec, VC, ps, AT = FALSE){
+p1 <- p2 <- pdf1 <- pdf2 <- c.copula.be2 <- c.copula.be1 <- c.copula2.be1be2 <- NA
 
 etad <- etas1 <- etas2 <- l.ln <- NULL
 
@@ -16,7 +17,7 @@ inde.inf2 <- VC$inde.inf2
 
     eta1 <- VC$X1%*%params1
     Xd1P <- VC$Xd1%*%params1  
-    Xd1P <- ifelse(Xd1P < sqrt(.Machine$double.eps), sqrt(.Machine$double.eps), Xd1P )
+    Xd1P <- ifelse(Xd1P < VC$min.dn, VC$min.dn, Xd1P )
         
     params2 <- params[-c(1:VC$X1.d2)]
     
@@ -46,12 +47,12 @@ inde.inf2 <- VC$inde.inf2
     eta2 <- VC$X2%*%params2
     Xd2P <- VC$Xd2%*%params2
 
-    Xd2P <- ifelse(Xd2P < sqrt(.Machine$double.eps), sqrt(.Machine$double.eps), Xd2P )
+    Xd2P <- ifelse(Xd2P < VC$min.dn, VC$min.dn, Xd2P )
 
 ##################
     
-pd1 <- probmS(eta1, VC$margins[1])
-pd2 <- probmS(eta2, VC$margins[2])
+pd1 <- probmS(eta1, VC$margins[1], min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
+pd2 <- probmS(eta2, VC$margins[2], min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
   
 p1 <- pd1$pr
 p2 <- pd2$pr
@@ -225,7 +226,10 @@ if(VC$extra.regI == "sED") H <- regH(H, type = 2)
          list(value=res, gradient=G, hessian=H, S.h=S.h, S.h1=S.h1, S.h2=S.h2,
               l=S.res, l.ln = l.ln, l.par=l.par, ps = ps, params1 = params1, params2 = params2,
               eta1=eta1, eta2 = eta2, 
-              p1 = p1,
+                                   p1 = p1, p2 = p2, pdf1 = -dS1eta1, pdf2 = -dS2eta2,          
+	      	                           c.copula.be2 = c.copula.be2,
+	      	                           c.copula.be1 = c.copula.be1,
+              c.copula2.be1be2 = c.copula2.be1be2,
               dl.dbe1          = NULL,       
               dl.dbe2          = NULL,       
               dl.dteta.st      = NULL)
