@@ -152,9 +152,12 @@ if(x$margins[1] %in% x$bl && is.null(x$K1)) cat("\nMARGIN 1: Bernoulli")
 if(x$margins[1] %in% x$bl && !is.null(x$K1)) cat("\nMARGIN 1: categorical") 
 
 
-if(x$margins[2] %in% x$bl) cat("\nMARGIN 2: Bernoulli") 
+if(x$margins[2] %in% x$bl && is.null(x$K2)) cat("\nMARGIN 2: Bernoulli") 
+if(x$margins[2] %in% x$bl && !is.null(x$K2)) cat("\nMARGIN 2: categorical") 
 
 
+if(is.null(x$K2)){
+
 if(x$margins[2]%in%c("N"))           cat("\nMARGIN 2: Gaussian")  
 if(x$margins[2]=="GP")               cat("\nMARGIN 2: generalised Pareto")  
 if(x$margins[2]=="GPII")             cat("\nMARGIN 2: generalised Pareto II")  
@@ -193,6 +196,9 @@ if(x$margins[2]=="ZTP")    	       cat("\nMARGIN 2: Zero Truncated Poisson")
 }
 
 
+}
+
+
 
 
 if(type == "ROY"){
